"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const aws_utils_1 = require("../aws-utils");
(0, vitest_1.describe)("test aws utils", () => {
    vitest_1.test.each([
        `'�K*��z:event-typechunk'`,
        `':content-typeapplication/json'`,
        `':message-typeevent{"bytes":"eyJldmVudF90eXBlIjoidGV4dC1nZW5lcmF0aW9uIiwiaXNfZmluaXNoZWQiOmZhbHNlLCJ0ZXh0IjoiSGVsbG8ifQ=="}�B@Q�K�;~t:event-typechunk'`,
        `':message-typeevent{"bytes":"eyJldmVudF90eXBlIjoidGV4dC1nZW5lcmF0aW9uIiwiaXNfZmluaXNoZWQiOmZhbHNlLCJ0ZXh0IjoiISJ9"}V�6��K�ش:event-typechunk'`,
    ])("parseAWSEvent ", (event) => {
        (0, vitest_1.expect)((0, aws_utils_1.parseAWSEvent)(event)).toMatchSnapshot();
    });
});
